# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from marqeta_client.models.jit_funding_paymentcard_funding_source import JitFundingPaymentcardFundingSource
from marqeta_client.models.jit_funding_program_funding_source import JitFundingProgramFundingSource
from marqeta_client.models.jit_funding_programgateway_funding_source import JitFundingProgramgatewayFundingSource

class JitFunding(BaseModel):
    """
    JitFunding
    """
    paymentcard_funding_source: Optional[JitFundingPaymentcardFundingSource] = None
    programgateway_funding_source: Optional[JitFundingProgramgatewayFundingSource] = None
    program_funding_source: Optional[JitFundingProgramFundingSource] = None
    __properties = ["paymentcard_funding_source", "programgateway_funding_source", "program_funding_source"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> JitFunding:
        """Create an instance of JitFunding from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of paymentcard_funding_source
        if self.paymentcard_funding_source:
            _dict['paymentcard_funding_source'] = self.paymentcard_funding_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of programgateway_funding_source
        if self.programgateway_funding_source:
            _dict['programgateway_funding_source'] = self.programgateway_funding_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of program_funding_source
        if self.program_funding_source:
            _dict['program_funding_source'] = self.program_funding_source.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> JitFunding:
        """Create an instance of JitFunding from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return JitFunding.parse_obj(obj)

        _obj = JitFunding.parse_obj({
            "paymentcard_funding_source": JitFundingPaymentcardFundingSource.from_dict(obj.get("paymentcard_funding_source")) if obj.get("paymentcard_funding_source") is not None else None,
            "programgateway_funding_source": JitFundingProgramgatewayFundingSource.from_dict(obj.get("programgateway_funding_source")) if obj.get("programgateway_funding_source") is not None else None,
            "program_funding_source": JitFundingProgramFundingSource.from_dict(obj.get("program_funding_source")) if obj.get("program_funding_source") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictStr, validator

class TranLogAttributeRequest(BaseModel):
    """
    TranLogAttributeRequest
    """
    transaction_token: StrictStr = ...
    attribute_name: StrictStr = ...
    attribute_value: StrictStr = ...
    __properties = ["transaction_token", "attribute_name", "attribute_value"]

    @validator('attribute_name')
    def attribute_name_validate_enum(cls, v):
        if v not in ('FUEL_TYPE', 'NUM_GALLONS', 'PRICE_PER_GALLON', 'EARN_CARDHOLDER_REWARD', 'TRAN_LIFE_CYCLE', 'MULTI_CLEARING_SEQ', 'MULTI_CLEARING_FINAL_COMPLETION_ID', 'POS_ENTRY_CODE', 'PROCESSING_CODE', 'INTERCHANGE_RATE_DESCRIPTOR', 'TERMINAL_TYPE', 'SETTLEMENT_INDICATOR', 'CARD_PRESENT', 'CARD_HOLDER_PRESENT', 'TRAN_ORIGIN', 'FIND_ORIGINAL_FINDER', 'MANUAL_NOTE', 'POST_DATE_MODIFICATION', 'CLEARING_RECORD_HASH', 'CLEARING_RAW_RECORD_HASH', 'CLEARING_RECORD_FILE_NAME', 'CLEARING_RECORD_SEQUENCE_NUMBER', 'TOKEN_ELAPSED_TIME_TO_LIVE_FOR_AN_LUK', 'TOKEN_COUNT_OF_TRANSACTION_FOR_AN_LUK', 'TOKEN_CUMULATIVE_TOTAL_TRANSACTION_AMOUNT_FOR_AN_LUK', 'INCREMENTAL_CUMULATIVE_AMOUNT', 'FINAL_INCREMENTAL_AUTH', 'NETWORK_FEES_MODEL', 'ECOMMERCE_SECURITY_LEVEL_INDICATOR', 'PAYMENT_CHANNEL', 'PAYMENT_INSTRUMENT', 'PAYMENT_ACCOUNT_REFERENCE', 'PIN_PRESENT', 'TERMINAL_PARTIAL_APPROVAL_CAPABLE', 'STIP_REASON_CODE', 'STIP_EXTENDED_REASON_CODE', 'IS_RECURRING', 'IS_INSTALLMENT', 'TRANSACTION_INTEGRITY_CLASS', 'DYNAMIC_CVV_ATC', 'STANDIN_APPROVED_BY', 'STANDIN_BY', 'ORIGINAL_CURRENCY_CODE', 'DYNAMIC_CURRENCY_CONVERSION', 'CARDHOLDER_BILLING_CONVERSION_RATE', 'CARDHOLDER_BILLING_CONVERSION_DATE', 'IS_IT_STIP_APPROVAL', 'ECOMMERCE_AUTHENTICATION_DATA', 'CAVV_RESULT_CODE', 'NETWORK_TRANSACTION_AMOUNT_DE_4', 'NETWORK_SETTLEMENT_AMOUNT_DE_5', 'NETWORK_CARDHOLDER_BILLING_AMOUNT_DE_6', 'NETWORK_FEE_AMOUNT_DE_28', 'NETWORK_CASHBACK_AMOUNT_OTHER_DE_54', 'NETWORK_REPLACEMENT_AMOUNT_OTHER_DE_61', 'NETWORK_REPLACEMENT_AMOUNT_DE_95', 'ADVICE_DETAIL_CODE', 'ASYNC_REQUEST_TOKEN', 'TXN_MCC', 'EXTRA_FIELDS', 'SURCHARGE_FREE_ATM_NETWORK', 'NETWORK_PRODUCT_ID', 'NETWORK_PROGRAM_ID', 'NETWORK_SPEND_QUALIFIER', 'THREE_DS_CAVV_VERSION', 'THREE_DS_MESSAGE_VERSION', 'THREE_DS_AUTHENTICATION_METHOD', 'THREE_DS_AUTHENTICATION_STATUS', 'THREE_DS_ACQUIRER_EXEMPTION', 'MOTO_INDICATOR', 'PREAUTH_TIME_LIMIT', 'AUTHORIZATION_SOURCE_CODE', 'OCT_UNIQUE_TRANSACTION_REFERENCE_NUMBER', 'IS_FUNDING_TRANSACTION', 'CARDHOLDER_SETTLEMENT_CONVERSION_RATE', 'SETTLEMENT_CURRENCY_CODE', 'ENHANCED_DATA_TOKEN', 'DD_EARLY_PAY_ELIGIBLE', 'DD_EARLY_PAY_SETTLEMENT_DATE', 'CURRENCY_CONVERSION_ASSESSMENT', 'THREE_DS_ISSUER_EXEMPTION', 'MERCHANT_TAX_ID', 'MERCHANT_ORIGIN_COUNTRY_CODE', 'NETWORK_ACCOUNT_INTELLIGENCE_SCORE', 'NETWORK_ASSIGNED_ID', 'REAL_TIME_FEE_TYPE', 'OCT_TYPE', 'ONE_LEG_OUT', 'ATC_VALUE', 'ATC_DISCREPANCY_VALUE', 'ATC_DISCREPANCY_INDICATOR', 'ISA_INDICATOR', 'ACCOUNT_IDENTIFICATION_1', 'INSTALLMENT_PAYMENT_FREQUENCY', 'INSTALLMENT_PAYMENT_FIRST_INSTALLMENT_DATE', 'INSTALLMENT_PAYMENT_TOTAL_AMOUNT_FUNDED', 'INSTALLMENT_PAYMENT_PAYMENT_TYPE'):
            raise ValueError("must be one of enum values ('FUEL_TYPE', 'NUM_GALLONS', 'PRICE_PER_GALLON', 'EARN_CARDHOLDER_REWARD', 'TRAN_LIFE_CYCLE', 'MULTI_CLEARING_SEQ', 'MULTI_CLEARING_FINAL_COMPLETION_ID', 'POS_ENTRY_CODE', 'PROCESSING_CODE', 'INTERCHANGE_RATE_DESCRIPTOR', 'TERMINAL_TYPE', 'SETTLEMENT_INDICATOR', 'CARD_PRESENT', 'CARD_HOLDER_PRESENT', 'TRAN_ORIGIN', 'FIND_ORIGINAL_FINDER', 'MANUAL_NOTE', 'POST_DATE_MODIFICATION', 'CLEARING_RECORD_HASH', 'CLEARING_RAW_RECORD_HASH', 'CLEARING_RECORD_FILE_NAME', 'CLEARING_RECORD_SEQUENCE_NUMBER', 'TOKEN_ELAPSED_TIME_TO_LIVE_FOR_AN_LUK', 'TOKEN_COUNT_OF_TRANSACTION_FOR_AN_LUK', 'TOKEN_CUMULATIVE_TOTAL_TRANSACTION_AMOUNT_FOR_AN_LUK', 'INCREMENTAL_CUMULATIVE_AMOUNT', 'FINAL_INCREMENTAL_AUTH', 'NETWORK_FEES_MODEL', 'ECOMMERCE_SECURITY_LEVEL_INDICATOR', 'PAYMENT_CHANNEL', 'PAYMENT_INSTRUMENT', 'PAYMENT_ACCOUNT_REFERENCE', 'PIN_PRESENT', 'TERMINAL_PARTIAL_APPROVAL_CAPABLE', 'STIP_REASON_CODE', 'STIP_EXTENDED_REASON_CODE', 'IS_RECURRING', 'IS_INSTALLMENT', 'TRANSACTION_INTEGRITY_CLASS', 'DYNAMIC_CVV_ATC', 'STANDIN_APPROVED_BY', 'STANDIN_BY', 'ORIGINAL_CURRENCY_CODE', 'DYNAMIC_CURRENCY_CONVERSION', 'CARDHOLDER_BILLING_CONVERSION_RATE', 'CARDHOLDER_BILLING_CONVERSION_DATE', 'IS_IT_STIP_APPROVAL', 'ECOMMERCE_AUTHENTICATION_DATA', 'CAVV_RESULT_CODE', 'NETWORK_TRANSACTION_AMOUNT_DE_4', 'NETWORK_SETTLEMENT_AMOUNT_DE_5', 'NETWORK_CARDHOLDER_BILLING_AMOUNT_DE_6', 'NETWORK_FEE_AMOUNT_DE_28', 'NETWORK_CASHBACK_AMOUNT_OTHER_DE_54', 'NETWORK_REPLACEMENT_AMOUNT_OTHER_DE_61', 'NETWORK_REPLACEMENT_AMOUNT_DE_95', 'ADVICE_DETAIL_CODE', 'ASYNC_REQUEST_TOKEN', 'TXN_MCC', 'EXTRA_FIELDS', 'SURCHARGE_FREE_ATM_NETWORK', 'NETWORK_PRODUCT_ID', 'NETWORK_PROGRAM_ID', 'NETWORK_SPEND_QUALIFIER', 'THREE_DS_CAVV_VERSION', 'THREE_DS_MESSAGE_VERSION', 'THREE_DS_AUTHENTICATION_METHOD', 'THREE_DS_AUTHENTICATION_STATUS', 'THREE_DS_ACQUIRER_EXEMPTION', 'MOTO_INDICATOR', 'PREAUTH_TIME_LIMIT', 'AUTHORIZATION_SOURCE_CODE', 'OCT_UNIQUE_TRANSACTION_REFERENCE_NUMBER', 'IS_FUNDING_TRANSACTION', 'CARDHOLDER_SETTLEMENT_CONVERSION_RATE', 'SETTLEMENT_CURRENCY_CODE', 'ENHANCED_DATA_TOKEN', 'DD_EARLY_PAY_ELIGIBLE', 'DD_EARLY_PAY_SETTLEMENT_DATE', 'CURRENCY_CONVERSION_ASSESSMENT', 'THREE_DS_ISSUER_EXEMPTION', 'MERCHANT_TAX_ID', 'MERCHANT_ORIGIN_COUNTRY_CODE', 'NETWORK_ACCOUNT_INTELLIGENCE_SCORE', 'NETWORK_ASSIGNED_ID', 'REAL_TIME_FEE_TYPE', 'OCT_TYPE', 'ONE_LEG_OUT', 'ATC_VALUE', 'ATC_DISCREPANCY_VALUE', 'ATC_DISCREPANCY_INDICATOR', 'ISA_INDICATOR', 'ACCOUNT_IDENTIFICATION_1', 'INSTALLMENT_PAYMENT_FREQUENCY', 'INSTALLMENT_PAYMENT_FIRST_INSTALLMENT_DATE', 'INSTALLMENT_PAYMENT_TOTAL_AMOUNT_FUNDED', 'INSTALLMENT_PAYMENT_PAYMENT_TYPE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TranLogAttributeRequest:
        """Create an instance of TranLogAttributeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TranLogAttributeRequest:
        """Create an instance of TranLogAttributeRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TranLogAttributeRequest.parse_obj(obj)

        _obj = TranLogAttributeRequest.parse_obj({
            "transaction_token": obj.get("transaction_token"),
            "attribute_name": obj.get("attribute_name"),
            "attribute_value": obj.get("attribute_value")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, validator

class RealTimeFeeAssessmentRequest(BaseModel):
    """
    RealTimeFeeAssessmentRequest
    """
    transaction_type: Optional[StrictStr] = None
    international_enabled: Optional[StrictBool] = False
    domestic_enabled: Optional[StrictBool] = False
    __properties = ["transaction_type", "international_enabled", "domestic_enabled"]

    @validator('transaction_type')
    def transaction_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('authorization', 'pindebit.atm.withdrawal', 'pindebit'):
            raise ValueError("must be one of enum values ('authorization', 'pindebit.atm.withdrawal', 'pindebit')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RealTimeFeeAssessmentRequest:
        """Create an instance of RealTimeFeeAssessmentRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RealTimeFeeAssessmentRequest:
        """Create an instance of RealTimeFeeAssessmentRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return RealTimeFeeAssessmentRequest.parse_obj(obj)

        _obj = RealTimeFeeAssessmentRequest.parse_obj({
            "transaction_type": obj.get("transaction_type"),
            "international_enabled": obj.get("international_enabled") if obj.get("international_enabled") is not None else False,
            "domestic_enabled": obj.get("domestic_enabled") if obj.get("domestic_enabled") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from marqeta_client.models.internal_crypto_key_request import InternalCryptoKeyRequest

class InternalCryptoKeyRequestModel(BaseModel):
    """
    InternalCryptoKeyRequestModel
    """
    crypto_keys: conlist(InternalCryptoKeyRequest, max_items=2147483647, min_items=1) = Field(..., description="A list of 'internal crypto key' items")
    __properties = ["crypto_keys"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalCryptoKeyRequestModel:
        """Create an instance of InternalCryptoKeyRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in crypto_keys (list)
        _items = []
        if self.crypto_keys:
            for _item in self.crypto_keys:
                if _item:
                    _items.append(_item.to_dict())
            _dict['crypto_keys'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalCryptoKeyRequestModel:
        """Create an instance of InternalCryptoKeyRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalCryptoKeyRequestModel.parse_obj(obj)

        _obj = InternalCryptoKeyRequestModel.parse_obj({
            "crypto_keys": [InternalCryptoKeyRequest.from_dict(_item) for _item in obj.get("crypto_keys")] if obj.get("crypto_keys") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator
from marqeta_client.models.card_personalization import CardPersonalization
from marqeta_client.models.shipping import Shipping

class CardProductFulfillment(BaseModel):
    """
    CardProductFulfillment
    """
    shipping: Optional[Shipping] = None
    card_personalization: CardPersonalization = ...
    payment_instrument: Optional[StrictStr] = 'PHYSICAL_MSR'
    package_id: Optional[constr(strict=True, max_length=50, min_length=1)] = '0'
    all_zero_card_security_code: Optional[StrictBool] = False
    bin_prefix: Optional[StrictStr] = None
    bulk_ship: Optional[StrictBool] = False
    pan_length: Optional[StrictStr] = '16'
    fulfillment_provider: Optional[StrictStr] = 'PERFECTPLASTIC'
    allow_card_creation: Optional[StrictBool] = True
    uppercase_name_lines: Optional[StrictBool] = True
    enable_offline_pin: Optional[StrictBool] = False
    __properties = ["shipping", "card_personalization", "payment_instrument", "package_id", "all_zero_card_security_code", "bin_prefix", "bulk_ship", "pan_length", "fulfillment_provider", "allow_card_creation", "uppercase_name_lines", "enable_offline_pin"]

    @validator('payment_instrument')
    def payment_instrument_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PHYSICAL_MSR', 'PHYSICAL_ICC', 'PHYSICAL_CONTACTLESS', 'PHYSICAL_COMBO', 'VIRTUAL_PAN'):
            raise ValueError("must be one of enum values ('PHYSICAL_MSR', 'PHYSICAL_ICC', 'PHYSICAL_CONTACTLESS', 'PHYSICAL_COMBO', 'VIRTUAL_PAN')")
        return v

    @validator('fulfillment_provider')
    def fulfillment_provider_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PERFECTPLASTIC', 'ARROWEYE', 'IDEMIA', 'IDEMIA_UK', 'IDEMIA_FR', 'IDEMIA_CZ', 'IDEMIA_APAC', 'IDEMIA_PL', 'IDEMIA_AU', 'IDEMIA_LA', 'GEMALTO', 'NITECREST', 'OBERTHUR', 'ALLPAY'):
            raise ValueError("must be one of enum values ('PERFECTPLASTIC', 'ARROWEYE', 'IDEMIA', 'IDEMIA_UK', 'IDEMIA_FR', 'IDEMIA_CZ', 'IDEMIA_APAC', 'IDEMIA_PL', 'IDEMIA_AU', 'IDEMIA_LA', 'GEMALTO', 'NITECREST', 'OBERTHUR', 'ALLPAY')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardProductFulfillment:
        """Create an instance of CardProductFulfillment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of shipping
        if self.shipping:
            _dict['shipping'] = self.shipping.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_personalization
        if self.card_personalization:
            _dict['card_personalization'] = self.card_personalization.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardProductFulfillment:
        """Create an instance of CardProductFulfillment from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardProductFulfillment.parse_obj(obj)

        _obj = CardProductFulfillment.parse_obj({
            "shipping": Shipping.from_dict(obj.get("shipping")) if obj.get("shipping") is not None else None,
            "card_personalization": CardPersonalization.from_dict(obj.get("card_personalization")) if obj.get("card_personalization") is not None else None,
            "payment_instrument": obj.get("payment_instrument") if obj.get("payment_instrument") is not None else 'PHYSICAL_MSR',
            "package_id": obj.get("package_id") if obj.get("package_id") is not None else '0',
            "all_zero_card_security_code": obj.get("all_zero_card_security_code") if obj.get("all_zero_card_security_code") is not None else False,
            "bin_prefix": obj.get("bin_prefix"),
            "bulk_ship": obj.get("bulk_ship") if obj.get("bulk_ship") is not None else False,
            "pan_length": obj.get("pan_length") if obj.get("pan_length") is not None else '16',
            "fulfillment_provider": obj.get("fulfillment_provider") if obj.get("fulfillment_provider") is not None else 'PERFECTPLASTIC',
            "allow_card_creation": obj.get("allow_card_creation") if obj.get("allow_card_creation") is not None else True,
            "uppercase_name_lines": obj.get("uppercase_name_lines") if obj.get("uppercase_name_lines") is not None else True,
            "enable_offline_pin": obj.get("enable_offline_pin") if obj.get("enable_offline_pin") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt

class AchVerificationModel(BaseModel):
    """
    AchVerificationModel
    """
    verify_amount1: Optional[Union[StrictFloat, StrictInt]] = None
    verify_amount2: Optional[Union[StrictFloat, StrictInt]] = None
    active: Optional[StrictBool] = False
    __properties = ["verify_amount1", "verify_amount2", "active"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AchVerificationModel:
        """Create an instance of AchVerificationModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AchVerificationModel:
        """Create an instance of AchVerificationModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AchVerificationModel.parse_obj(obj)

        _obj = AchVerificationModel.parse_obj({
            "verify_amount1": obj.get("verify_amount1"),
            "verify_amount2": obj.get("verify_amount2"),
            "active": obj.get("active") if obj.get("active") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, confloat, conint

class PreKycControls(BaseModel):
    """
    PreKycControls
    """
    cash_access_enabled: Optional[StrictBool] = False
    international_enabled: Optional[StrictBool] = False
    balance_max: Optional[Union[confloat(ge=0.01, strict=True), conint(ge=1, strict=True)]] = Field(None, description="Minimum is 0.01")
    enable_non_program_loads: Optional[StrictBool] = False
    is_reloadable_pre_kyc: Optional[StrictBool] = False
    __properties = ["cash_access_enabled", "international_enabled", "balance_max", "enable_non_program_loads", "is_reloadable_pre_kyc"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PreKycControls:
        """Create an instance of PreKycControls from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PreKycControls:
        """Create an instance of PreKycControls from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PreKycControls.parse_obj(obj)

        _obj = PreKycControls.parse_obj({
            "cash_access_enabled": obj.get("cash_access_enabled") if obj.get("cash_access_enabled") is not None else False,
            "international_enabled": obj.get("international_enabled") if obj.get("international_enabled") is not None else False,
            "balance_max": obj.get("balance_max"),
            "enable_non_program_loads": obj.get("enable_non_program_loads") if obj.get("enable_non_program_loads") is not None else False,
            "is_reloadable_pre_kyc": obj.get("is_reloadable_pre_kyc") if obj.get("is_reloadable_pre_kyc") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, constr, validator

class FileProcessingRequest(BaseModel):
    """
    FileProcessingRequest
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    file_process_type: StrictStr = ...
    source_file: constr(strict=True, max_length=512, min_length=0) = ...
    archive_file: Optional[constr(strict=True, max_length=512, min_length=0)] = None
    __properties = ["token", "file_process_type", "source_file", "archive_file"]

    @validator('file_process_type')
    def file_process_type_validate_enum(cls, v):
        if v not in ('MASTERCARD_CLEARING', 'VISA_CLEARING', 'PULSE_CLEARING', 'DISCOVER_CLEARING'):
            raise ValueError("must be one of enum values ('MASTERCARD_CLEARING', 'VISA_CLEARING', 'PULSE_CLEARING', 'DISCOVER_CLEARING')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FileProcessingRequest:
        """Create an instance of FileProcessingRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FileProcessingRequest:
        """Create an instance of FileProcessingRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FileProcessingRequest.parse_obj(obj)

        _obj = FileProcessingRequest.parse_obj({
            "token": obj.get("token"),
            "file_process_type": obj.get("file_process_type"),
            "source_file": obj.get("source_file"),
            "archive_file": obj.get("archive_file")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class Authentication(BaseModel):
    """
    Authentication
    """
    last_password_update_channel: Optional[StrictStr] = None
    last_password_update_time: Optional[datetime] = Field(None, description="yyyy-MM-ddTHH:mm:ssZ")
    email_verified: Optional[StrictBool] = False
    email_verified_time: Optional[datetime] = Field(None, description="yyyy-MM-ddTHH:mm:ssZ")
    __properties = ["last_password_update_channel", "last_password_update_time", "email_verified", "email_verified_time"]

    @validator('last_password_update_channel')
    def last_password_update_channel_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('USER_CHANGE', 'USER_RESET'):
            raise ValueError("must be one of enum values ('USER_CHANGE', 'USER_RESET')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Authentication:
        """Create an instance of Authentication from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Authentication:
        """Create an instance of Authentication from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Authentication.parse_obj(obj)

        _obj = Authentication.parse_obj({
            "last_password_update_channel": obj.get("last_password_update_channel"),
            "last_password_update_time": obj.get("last_password_update_time"),
            "email_verified": obj.get("email_verified") if obj.get("email_verified") is not None else False,
            "email_verified_time": obj.get("email_verified_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from marqeta_client.models.terminal_model import TerminalModel

class TransactionCardAcceptor(BaseModel):
    """
    TransactionCardAcceptor
    """
    mid: Optional[StrictStr] = None
    mcc: Optional[StrictStr] = None
    network_mid: Optional[StrictStr] = None
    mcc_groups: Optional[conlist(StrictStr)] = None
    merchant_tax_id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    address: Optional[StrictStr] = None
    city: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    postal_code: Optional[StrictStr] = None
    country_code: Optional[StrictStr] = None
    poi: Optional[TerminalModel] = None
    payment_facilitator_id: Optional[StrictStr] = None
    independent_sales_organization_id: Optional[StrictStr] = None
    sub_merchant_id: Optional[StrictStr] = None
    network_assigned_id: Optional[StrictStr] = None
    country_of_origin: Optional[StrictStr] = None
    transfer_service_provider_name: Optional[StrictStr] = None
    payment_facilitator_name: Optional[StrictStr] = None
    __properties = ["mid", "mcc", "network_mid", "mcc_groups", "merchant_tax_id", "name", "address", "city", "state", "postal_code", "country_code", "poi", "payment_facilitator_id", "independent_sales_organization_id", "sub_merchant_id", "network_assigned_id", "country_of_origin", "transfer_service_provider_name", "payment_facilitator_name"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransactionCardAcceptor:
        """Create an instance of TransactionCardAcceptor from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of poi
        if self.poi:
            _dict['poi'] = self.poi.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransactionCardAcceptor:
        """Create an instance of TransactionCardAcceptor from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TransactionCardAcceptor.parse_obj(obj)

        _obj = TransactionCardAcceptor.parse_obj({
            "mid": obj.get("mid"),
            "mcc": obj.get("mcc"),
            "network_mid": obj.get("network_mid"),
            "mcc_groups": obj.get("mcc_groups"),
            "merchant_tax_id": obj.get("merchant_tax_id"),
            "name": obj.get("name"),
            "address": obj.get("address"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "postal_code": obj.get("postal_code"),
            "country_code": obj.get("country_code"),
            "poi": TerminalModel.from_dict(obj.get("poi")) if obj.get("poi") is not None else None,
            "payment_facilitator_id": obj.get("payment_facilitator_id"),
            "independent_sales_organization_id": obj.get("independent_sales_organization_id"),
            "sub_merchant_id": obj.get("sub_merchant_id"),
            "network_assigned_id": obj.get("network_assigned_id"),
            "country_of_origin": obj.get("country_of_origin"),
            "transfer_service_provider_name": obj.get("transfer_service_provider_name"),
            "payment_facilitator_name": obj.get("payment_facilitator_name")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, constr

class DirectDepositAccountResponse(BaseModel):
    """
    DirectDepositAccountResponse
    """
    account_number: constr(strict=True, max_length=17, min_length=13) = ...
    routing_number: constr(strict=True, max_length=9, min_length=9) = ...
    token: constr(strict=True, max_length=36, min_length=36) = ...
    user_token: constr(strict=True, max_length=36, min_length=36) = ...
    business_token: constr(strict=True, max_length=36, min_length=36) = ...
    state: constr(strict=True, max_length=10, min_length=6) = ...
    allow_immediate_credit: StrictBool = ...
    type: Optional[constr(strict=True, max_length=36, min_length=7)] = None
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    __properties = ["account_number", "routing_number", "token", "user_token", "business_token", "state", "allow_immediate_credit", "type", "created_time", "last_modified_time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DirectDepositAccountResponse:
        """Create an instance of DirectDepositAccountResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DirectDepositAccountResponse:
        """Create an instance of DirectDepositAccountResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DirectDepositAccountResponse.parse_obj(obj)

        _obj = DirectDepositAccountResponse.parse_obj({
            "account_number": obj.get("account_number"),
            "routing_number": obj.get("routing_number"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "state": obj.get("state"),
            "allow_immediate_credit": obj.get("allow_immediate_credit") if obj.get("allow_immediate_credit") is not None else False,
            "type": obj.get("type"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist, validator
from marqeta_client.models.internal_card import InternalCard
from marqeta_client.models.internal_user import InternalUser

class InternalAuthControlRequest(BaseModel):
    """
    InternalAuthControlRequest
    """
    card: InternalCard = ...
    cardholder: InternalUser = ...
    mid: Optional[StrictStr] = None
    mcc: Optional[StrictStr] = None
    mcc_groups: Optional[conlist(StrictStr)] = None
    controls_indicator: StrictStr = ...
    network: Optional[StrictStr] = None
    itc: Optional[StrictStr] = None
    business_application_identifier: Optional[StrictStr] = None
    __properties = ["card", "cardholder", "mid", "mcc", "mcc_groups", "controls_indicator", "network", "itc", "business_application_identifier"]

    @validator('controls_indicator')
    def controls_indicator_validate_enum(cls, v):
        if v not in ('LOAD', 'SPEND'):
            raise ValueError("must be one of enum values ('LOAD', 'SPEND')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalAuthControlRequest:
        """Create an instance of InternalAuthControlRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cardholder
        if self.cardholder:
            _dict['cardholder'] = self.cardholder.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalAuthControlRequest:
        """Create an instance of InternalAuthControlRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalAuthControlRequest.parse_obj(obj)

        _obj = InternalAuthControlRequest.parse_obj({
            "card": InternalCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "cardholder": InternalUser.from_dict(obj.get("cardholder")) if obj.get("cardholder") is not None else None,
            "mid": obj.get("mid"),
            "mcc": obj.get("mcc"),
            "mcc_groups": obj.get("mcc_groups"),
            "controls_indicator": obj.get("controls_indicator"),
            "network": obj.get("network"),
            "itc": obj.get("itc"),
            "business_application_identifier": obj.get("business_application_identifier")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, validator
from marqeta_client.models.activation_actions import ActivationActions
from marqeta_client.models.card_fulfillment_response import CardFulfillmentResponse

class CardResponse(BaseModel):
    """
    CardResponse
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    token: StrictStr = Field(..., description="36 char max")
    user_token: StrictStr = Field(..., description="36 char max")
    card_product_token: StrictStr = Field(..., description="36 char max")
    last_four: StrictStr = ...
    pan: StrictStr = ...
    expiration: StrictStr = ...
    expiration_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    cvv_number: Optional[StrictStr] = None
    chip_cvv_number: Optional[StrictStr] = None
    barcode: StrictStr = ...
    pin_is_set: StrictBool = ...
    state: StrictStr = ...
    state_reason: StrictStr = ...
    fulfillment_status: StrictStr = ...
    reissue_pan_from_card_token: Optional[StrictStr] = None
    new_pan_from_card_token: Optional[StrictStr] = None
    fulfillment: Optional[CardFulfillmentResponse] = None
    bulk_issuance_token: Optional[StrictStr] = None
    translate_pin_from_card_token: Optional[StrictStr] = None
    activation_actions: Optional[ActivationActions] = None
    instrument_type: Optional[StrictStr] = None
    expedite: Optional[StrictBool] = False
    metadata: Optional[Dict[str, StrictStr]] = None
    contactless_exemption_counter: Optional[StrictInt] = None
    contactless_exemption_total_amount: Optional[Union[StrictFloat, StrictInt]] = None
    __properties = ["created_time", "last_modified_time", "token", "user_token", "card_product_token", "last_four", "pan", "expiration", "expiration_time", "cvv_number", "chip_cvv_number", "barcode", "pin_is_set", "state", "state_reason", "fulfillment_status", "reissue_pan_from_card_token", "new_pan_from_card_token", "fulfillment", "bulk_issuance_token", "translate_pin_from_card_token", "activation_actions", "instrument_type", "expedite", "metadata", "contactless_exemption_counter", "contactless_exemption_total_amount"]

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('ACTIVE', 'SUSPENDED', 'TERMINATED', 'UNSUPPORTED', 'UNACTIVATED', 'LIMITED'):
            raise ValueError("must be one of enum values ('ACTIVE', 'SUSPENDED', 'TERMINATED', 'UNSUPPORTED', 'UNACTIVATED', 'LIMITED')")
        return v

    @validator('fulfillment_status')
    def fulfillment_status_validate_enum(cls, v):
        if v not in ('ISSUED', 'ORDERED', 'REORDERED', 'REJECTED', 'SHIPPED', 'DELIVERED', 'DIGITALLY_PRESENTED'):
            raise ValueError("must be one of enum values ('ISSUED', 'ORDERED', 'REORDERED', 'REJECTED', 'SHIPPED', 'DELIVERED', 'DIGITALLY_PRESENTED')")
        return v

    @validator('instrument_type')
    def instrument_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PHYSICAL_MSR', 'PHYSICAL_ICC', 'PHYSICAL_CONTACTLESS', 'PHYSICAL_COMBO', 'VIRTUAL_PAN'):
            raise ValueError("must be one of enum values ('PHYSICAL_MSR', 'PHYSICAL_ICC', 'PHYSICAL_CONTACTLESS', 'PHYSICAL_COMBO', 'VIRTUAL_PAN')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardResponse:
        """Create an instance of CardResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of fulfillment
        if self.fulfillment:
            _dict['fulfillment'] = self.fulfillment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of activation_actions
        if self.activation_actions:
            _dict['activation_actions'] = self.activation_actions.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardResponse:
        """Create an instance of CardResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardResponse.parse_obj(obj)

        _obj = CardResponse.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "card_product_token": obj.get("card_product_token"),
            "last_four": obj.get("last_four"),
            "pan": obj.get("pan"),
            "expiration": obj.get("expiration"),
            "expiration_time": obj.get("expiration_time"),
            "cvv_number": obj.get("cvv_number"),
            "chip_cvv_number": obj.get("chip_cvv_number"),
            "barcode": obj.get("barcode"),
            "pin_is_set": obj.get("pin_is_set") if obj.get("pin_is_set") is not None else False,
            "state": obj.get("state"),
            "state_reason": obj.get("state_reason"),
            "fulfillment_status": obj.get("fulfillment_status"),
            "reissue_pan_from_card_token": obj.get("reissue_pan_from_card_token"),
            "new_pan_from_card_token": obj.get("new_pan_from_card_token"),
            "fulfillment": CardFulfillmentResponse.from_dict(obj.get("fulfillment")) if obj.get("fulfillment") is not None else None,
            "bulk_issuance_token": obj.get("bulk_issuance_token"),
            "translate_pin_from_card_token": obj.get("translate_pin_from_card_token"),
            "activation_actions": ActivationActions.from_dict(obj.get("activation_actions")) if obj.get("activation_actions") is not None else None,
            "instrument_type": obj.get("instrument_type"),
            "expedite": obj.get("expedite") if obj.get("expedite") is not None else False,
            "metadata": obj.get("metadata"),
            "contactless_exemption_counter": obj.get("contactless_exemption_counter"),
            "contactless_exemption_total_amount": obj.get("contactless_exemption_total_amount")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist, constr, validator
from marqeta_client.models.card_acceptor_model import CardAcceptorModel
from marqeta_client.models.money_model import MoneyModel
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.network_metadata import NetworkMetadata
from marqeta_client.models.original_data_elements import OriginalDataElements
from marqeta_client.models.webhook import Webhook

class AdvancedClearingRequestModel(BaseModel):
    """
    AdvancedClearingRequestModel
    """
    network_fees: Optional[conlist(NetworkFeeModel)] = None
    webhook: Optional[Webhook] = None
    mid: Optional[constr(strict=True, max_length=50, min_length=1)] = None
    amount: Union[StrictFloat, StrictInt] = ...
    source_amount: Union[StrictFloat, StrictInt] = ...
    reconciliation_amount: Union[StrictFloat, StrictInt] = ...
    replacement_amount: Optional[Union[StrictFloat, StrictInt]] = None
    cardholder_billing_amount: Optional[Union[StrictFloat, StrictInt]] = None
    cashback: Optional[Union[StrictFloat, StrictInt]] = None
    local_transaction_amount: Optional[Union[StrictFloat, StrictInt]] = None
    local_currency_code: Optional[StrictStr] = None
    settlement_amount: Optional[Union[StrictFloat, StrictInt]] = None
    settlement_currency_code: Optional[StrictStr] = None
    settlement_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    cardholder_billing_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    cardholder_billing_currency: Optional[StrictStr] = None
    card_token: constr(strict=True, max_length=36, min_length=1) = ...
    card_hash: StrictStr = ...
    acquirer_reference_id: Optional[constr(strict=True, max_length=23, min_length=1)] = None
    rrn: Optional[constr(strict=True, max_length=16, min_length=1)] = None
    stan: Optional[constr(strict=True, max_length=12, min_length=1)] = None
    processing_code: Optional[constr(strict=True, max_length=2, min_length=2)] = None
    acquirer_fee: Optional[MoneyModel] = None
    issuer_fee: Optional[MoneyModel] = None
    function_code: Optional[constr(strict=True, max_length=3, min_length=3)] = None
    reason_code: Optional[constr(strict=True, max_length=4, min_length=4)] = None
    approval_code: Optional[constr(strict=True, max_length=6, min_length=1)] = None
    transaction_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    local_transaction_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    settlement_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    network_reference_id: Optional[constr(strict=True, max_length=16, min_length=1)] = None
    find_original_window_days: Optional[StrictInt] = None
    batch_number: Optional[StrictStr] = None
    batch_file_name: Optional[StrictStr] = None
    sequence_number: Optional[StrictStr] = None
    multi_clearing_count: Optional[StrictStr] = None
    network: Optional[StrictStr] = None
    sub_network: Optional[StrictStr] = Field(None, description="Defaults to VISANET if network is VISA")
    card_acceptor: Optional[CardAcceptorModel] = None
    currency_code: constr(strict=True, max_length=3, min_length=3) = ...
    original_data_elements: Optional[OriginalDataElements] = None
    preceding_related_transaction_token: Optional[StrictStr] = None
    send_expiration_date: Optional[StrictBool] = False
    simulate_batch_for_clearing_record_hash: Optional[StrictBool] = None
    isa_indicator: Optional[StrictStr] = None
    token_pan: Optional[constr(strict=True, max_length=16, min_length=1)] = None
    payment_channel_indicator: Optional[StrictStr] = None
    is_installment: Optional[StrictBool] = None
    is_recurring: Optional[StrictBool] = None
    network_metadata: Optional[NetworkMetadata] = None
    authorization_source_code: Optional[StrictStr] = None
    interchange_rate_descriptor: Optional[StrictStr] = None
    acquirer_institution_id_code: Optional[constr(strict=True, max_length=11, min_length=1)] = None
    terminal_id: Optional[constr(strict=True, max_length=8, min_length=1)] = None
    mti: Optional[StrictStr] = None
    clearing_file_name: Optional[StrictStr] = None
    __properties = ["network_fees", "webhook", "mid", "amount", "source_amount", "reconciliation_amount", "replacement_amount", "cardholder_billing_amount", "cashback", "local_transaction_amount", "local_currency_code", "settlement_amount", "settlement_currency_code", "settlement_conversion_rate", "cardholder_billing_conversion_rate", "cardholder_billing_currency", "card_token", "card_hash", "acquirer_reference_id", "rrn", "stan", "processing_code", "acquirer_fee", "issuer_fee", "function_code", "reason_code", "approval_code", "transaction_date", "local_transaction_date", "settlement_date", "network_reference_id", "find_original_window_days", "batch_number", "batch_file_name", "sequence_number", "multi_clearing_count", "network", "sub_network", "card_acceptor", "currency_code", "original_data_elements", "preceding_related_transaction_token", "send_expiration_date", "simulate_batch_for_clearing_record_hash", "isa_indicator", "token_pan", "payment_channel_indicator", "is_installment", "is_recurring", "network_metadata", "authorization_source_code", "interchange_rate_descriptor", "acquirer_institution_id_code", "terminal_id", "mti", "clearing_file_name"]

    @validator('network')
    def network_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('DISCOVER', 'MASTERCARD', 'PULSE', 'VISA'):
            raise ValueError("must be one of enum values ('DISCOVER', 'MASTERCARD', 'PULSE', 'VISA')")
        return v

    @validator('sub_network')
    def sub_network_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('VISANET', 'VISANETDEBIT', 'VISAINTERLINK', 'VISAPLUS'):
            raise ValueError("must be one of enum values ('VISANET', 'VISANETDEBIT', 'VISAINTERLINK', 'VISAPLUS')")
        return v

    @validator('isa_indicator')
    def isa_indicator_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('SINGLE_CURRENCY', 'MULTI_CURRENCY', 'REBATE_CANCELLED', 'MULTI_CURRENCY_NON_US_COUNTRIES', 'SINGLE_CURRENCY_PAID_BY_ISSUER', 'NO_CHARGE_ASSESSED'):
            raise ValueError("must be one of enum values ('SINGLE_CURRENCY', 'MULTI_CURRENCY', 'REBATE_CANCELLED', 'MULTI_CURRENCY_NON_US_COUNTRIES', 'SINGLE_CURRENCY_PAID_BY_ISSUER', 'NO_CHARGE_ASSESSED')")
        return v

    @validator('mti')
    def mti_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('0220', '0420'):
            raise ValueError("must be one of enum values ('0220', '0420')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AdvancedClearingRequestModel:
        """Create an instance of AdvancedClearingRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in network_fees (list)
        _items = []
        if self.network_fees:
            for _item in self.network_fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['network_fees'] = _items
        # override the default output from pydantic by calling `to_dict()` of webhook
        if self.webhook:
            _dict['webhook'] = self.webhook.to_dict()
        # override the default output from pydantic by calling `to_dict()` of acquirer_fee
        if self.acquirer_fee:
            _dict['acquirer_fee'] = self.acquirer_fee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of issuer_fee
        if self.issuer_fee:
            _dict['issuer_fee'] = self.issuer_fee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_acceptor
        if self.card_acceptor:
            _dict['card_acceptor'] = self.card_acceptor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_data_elements
        if self.original_data_elements:
            _dict['original_data_elements'] = self.original_data_elements.to_dict()
        # override the default output from pydantic by calling `to_dict()` of network_metadata
        if self.network_metadata:
            _dict['network_metadata'] = self.network_metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AdvancedClearingRequestModel:
        """Create an instance of AdvancedClearingRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AdvancedClearingRequestModel.parse_obj(obj)

        _obj = AdvancedClearingRequestModel.parse_obj({
            "network_fees": [NetworkFeeModel.from_dict(_item) for _item in obj.get("network_fees")] if obj.get("network_fees") is not None else None,
            "webhook": Webhook.from_dict(obj.get("webhook")) if obj.get("webhook") is not None else None,
            "mid": obj.get("mid"),
            "amount": obj.get("amount"),
            "source_amount": obj.get("source_amount"),
            "reconciliation_amount": obj.get("reconciliation_amount"),
            "replacement_amount": obj.get("replacement_amount"),
            "cardholder_billing_amount": obj.get("cardholder_billing_amount"),
            "cashback": obj.get("cashback"),
            "local_transaction_amount": obj.get("local_transaction_amount"),
            "local_currency_code": obj.get("local_currency_code"),
            "settlement_amount": obj.get("settlement_amount"),
            "settlement_currency_code": obj.get("settlement_currency_code"),
            "settlement_conversion_rate": obj.get("settlement_conversion_rate"),
            "cardholder_billing_conversion_rate": obj.get("cardholder_billing_conversion_rate"),
            "cardholder_billing_currency": obj.get("cardholder_billing_currency"),
            "card_token": obj.get("card_token"),
            "card_hash": obj.get("card_hash"),
            "acquirer_reference_id": obj.get("acquirer_reference_id"),
            "rrn": obj.get("rrn"),
            "stan": obj.get("stan"),
            "processing_code": obj.get("processing_code"),
            "acquirer_fee": MoneyModel.from_dict(obj.get("acquirer_fee")) if obj.get("acquirer_fee") is not None else None,
            "issuer_fee": MoneyModel.from_dict(obj.get("issuer_fee")) if obj.get("issuer_fee") is not None else None,
            "function_code": obj.get("function_code"),
            "reason_code": obj.get("reason_code"),
            "approval_code": obj.get("approval_code"),
            "transaction_date": obj.get("transaction_date"),
            "local_transaction_date": obj.get("local_transaction_date"),
            "settlement_date": obj.get("settlement_date"),
            "network_reference_id": obj.get("network_reference_id"),
            "find_original_window_days": obj.get("find_original_window_days"),
            "batch_number": obj.get("batch_number"),
            "batch_file_name": obj.get("batch_file_name"),
            "sequence_number": obj.get("sequence_number"),
            "multi_clearing_count": obj.get("multi_clearing_count"),
            "network": obj.get("network"),
            "sub_network": obj.get("sub_network"),
            "card_acceptor": CardAcceptorModel.from_dict(obj.get("card_acceptor")) if obj.get("card_acceptor") is not None else None,
            "currency_code": obj.get("currency_code"),
            "original_data_elements": OriginalDataElements.from_dict(obj.get("original_data_elements")) if obj.get("original_data_elements") is not None else None,
            "preceding_related_transaction_token": obj.get("preceding_related_transaction_token"),
            "send_expiration_date": obj.get("send_expiration_date") if obj.get("send_expiration_date") is not None else False,
            "simulate_batch_for_clearing_record_hash": obj.get("simulate_batch_for_clearing_record_hash"),
            "isa_indicator": obj.get("isa_indicator"),
            "token_pan": obj.get("token_pan"),
            "payment_channel_indicator": obj.get("payment_channel_indicator"),
            "is_installment": obj.get("is_installment"),
            "is_recurring": obj.get("is_recurring"),
            "network_metadata": NetworkMetadata.from_dict(obj.get("network_metadata")) if obj.get("network_metadata") is not None else None,
            "authorization_source_code": obj.get("authorization_source_code"),
            "interchange_rate_descriptor": obj.get("interchange_rate_descriptor"),
            "acquirer_institution_id_code": obj.get("acquirer_institution_id_code"),
            "terminal_id": obj.get("terminal_id"),
            "mti": obj.get("mti"),
            "clearing_file_name": obj.get("clearing_file_name")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, constr

class PrimaryContactInfoModel(BaseModel):
    """
    PrimaryContactInfoModel
    """
    full_name: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    title: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    department: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    phone: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    extension: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    fax: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    mobile: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    email: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    __properties = ["full_name", "title", "department", "phone", "extension", "fax", "mobile", "email"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PrimaryContactInfoModel:
        """Create an instance of PrimaryContactInfoModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PrimaryContactInfoModel:
        """Create an instance of PrimaryContactInfoModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PrimaryContactInfoModel.parse_obj(obj)

        _obj = PrimaryContactInfoModel.parse_obj({
            "full_name": obj.get("full_name"),
            "title": obj.get("title"),
            "department": obj.get("department"),
            "phone": obj.get("phone"),
            "extension": obj.get("extension"),
            "fax": obj.get("fax"),
            "mobile": obj.get("mobile"),
            "email": obj.get("email")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, constr, validator
from marqeta_client.models.card_acceptor_model import CardAcceptorModel
from marqeta_client.models.original_credit_sender_data import OriginalCreditSenderData
from marqeta_client.models.webhook import Webhook

class OrignalcreditRequestModel(BaseModel):
    """
    OrignalcreditRequestModel
    """
    transaction_purpose: Optional[StrictStr] = Field(None, alias="transactionPurpose")
    amount: Union[StrictFloat, StrictInt] = ...
    card_token: constr(strict=True, max_length=36, min_length=1) = ...
    mid: constr(strict=True, max_length=50, min_length=1) = ...
    screening_score: Optional[StrictStr] = None
    card_acceptor: Optional[CardAcceptorModel] = None
    type: StrictStr = ...
    sender_data: Optional[OriginalCreditSenderData] = None
    webhook: Optional[Webhook] = None
    __properties = ["transactionPurpose", "amount", "card_token", "mid", "screening_score", "card_acceptor", "type", "sender_data", "webhook"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('account_to_account', 'person_to_person', 'prepaid', 'wallet_transfer', 'money_transfer_by_bank', 'business_to_business', 'disbursement', 'government_disbursement', 'gambling_payout', 'loyalty', 'merchant_disbursement', 'online_gambling_payout', 'pension_disbursement', 'prepaid_loads', 'card_bill_payment', 'bill_payment', 'cash_claim', 'cash_in', 'cash_out', 'mobile_air_time_payment', 'money_transfer_by_merchant', 'face_to_face_merchant_payment', 'government_payment', 'payments_goods_services'):
            raise ValueError("must be one of enum values ('account_to_account', 'person_to_person', 'prepaid', 'wallet_transfer', 'money_transfer_by_bank', 'business_to_business', 'disbursement', 'government_disbursement', 'gambling_payout', 'loyalty', 'merchant_disbursement', 'online_gambling_payout', 'pension_disbursement', 'prepaid_loads', 'card_bill_payment', 'bill_payment', 'cash_claim', 'cash_in', 'cash_out', 'mobile_air_time_payment', 'money_transfer_by_merchant', 'face_to_face_merchant_payment', 'government_payment', 'payments_goods_services')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrignalcreditRequestModel:
        """Create an instance of OrignalcreditRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card_acceptor
        if self.card_acceptor:
            _dict['card_acceptor'] = self.card_acceptor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sender_data
        if self.sender_data:
            _dict['sender_data'] = self.sender_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of webhook
        if self.webhook:
            _dict['webhook'] = self.webhook.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrignalcreditRequestModel:
        """Create an instance of OrignalcreditRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return OrignalcreditRequestModel.parse_obj(obj)

        _obj = OrignalcreditRequestModel.parse_obj({
            "transaction_purpose": obj.get("transactionPurpose"),
            "amount": obj.get("amount"),
            "card_token": obj.get("card_token"),
            "mid": obj.get("mid"),
            "screening_score": obj.get("screening_score"),
            "card_acceptor": CardAcceptorModel.from_dict(obj.get("card_acceptor")) if obj.get("card_acceptor") is not None else None,
            "type": obj.get("type"),
            "sender_data": OriginalCreditSenderData.from_dict(obj.get("sender_data")) if obj.get("sender_data") is not None else None,
            "webhook": Webhook.from_dict(obj.get("webhook")) if obj.get("webhook") is not None else None
        })
        return _obj

